==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Input/wavpack/translations/wavpack_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>WavPack Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>WavPack Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="176"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="177"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="178"/>
        <source>WavPack library version:</source>
        <translation>WavPack kitaplık sürümü:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="180"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Ratio</source>
        <translation>Orantı</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Version</source>
        <translation>Uyarlama</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/wavpack/translations/wavpack_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="39"/>
        <source>WavPack Plugin</source>
        <translation>WavPack Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="41"/>
        <source>WavPack Files</source>
        <translation>WavPack Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="183"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="184"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="185"/>
        <source>WavPack library version:</source>
        <translation>WavPack kitaplık sürümü:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="187"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
